@@ -11,17 +11,6 @@ from droughty.config_cli import Common
 
 path = os.path.expanduser('~')
 
-def get_git_root(path):
-    
-        git_repo = git.Repo(path, search_parent_directories=True)
-        git_root = git_repo.git.rev_parse("--show-toplevel")
-        return (git_root)
-    
-##def return_git_path():
-    
-git_path = get_git_root(os.getcwd())
-
-
 ## profile vars
 @dataclass
 class IdentifyConfigVariables(Common):
@@ -30,6 +19,7 @@ class IdentifyConfigVariables(Common):
     profile_path: str
     project_path: str
     full_path: str
+    git_path: str
 
 def assign_droughty_paths():
 
@@ -43,7 +33,11 @@ def assign_droughty_paths():
 
         print ("Using environment variables")
 
-    try:
+    else:
+
+        pass
+
+    if Common.profile_dir != None:
 
         IdentifyConfigVariables.profile_path = Common.profile_dir
 
@@ -51,24 +45,32 @@ def assign_droughty_paths():
 
         print (Common.profile_dir)
 
-    except:
+    elif Common.profile_dir == None:
 
         path = os.path.expanduser('~')
 
-        IdentifyConfigVariables.profile_pass = os.path.join(path,".droughty/profile.yaml")       
+        IdentifyConfigVariables.profile_path = os.path.join(path,".droughty/profile.yaml")       
 
         print ("Using default profile path")
 
-    if IdentifyConfigVariables.profile_path == None:
+    elif IdentifyConfigVariables.profile_path == None:
 
         raise Exception ("It looks like you don't have a profile file or you have directly specified the incorrect directory")  
 
-paths = assign_droughty_paths()
+
+assign_droughty_paths()
+
+def get_git_root(path):
+    
+        git_repo = git.Repo(path, search_parent_directories=True)
+        git_root = git_repo.git.rev_parse("--show-toplevel")
+        return (git_root)
+
+IdentifyConfigVariables.git_path = get_git_root(os.getcwd())
+
 
 def load_droughty_profile():
 
-    IdentifyConfigVariables.project_path = Common.project_dir  
-
     with open(IdentifyConfigVariables.profile_path) as f:
 
         droughty_profile = yaml.load(f, Loader=yaml.FullLoader)
@@ -77,7 +79,7 @@ def load_droughty_profile():
 
 def assign_droughty_project_paths():
 
-    try:
+    if Common.project_dir != None:
 
         IdentifyConfigVariables.project_path = Common.project_dir  
 
@@ -88,25 +90,24 @@ def assign_droughty_project_paths():
         print (Common.project_dir)
 
 
-    except:
+    elif Common.project_dir == None:
 
-        IdentifyConfigVariables.project_path = Common.project_dir  
+        path = get_git_root(os.getcwd())
 
-        filename = 'droughty_project.yaml'
+        IdentifyConfigVariables.project_path = os.path.join(path,"droughty_project.yaml")       
 
-        droughty_project = os.path.join(git_path,filename)
+        print ("Using default project path")
 
-    if IdentifyConfigVariables.project_path == None:
+    else:
 
         raise Exception ("It looks like you don't have a droughty_project file or you have directly specified the incorrect directory")  
 
-project_path = assign_droughty_project_paths()
+
+assign_droughty_project_paths()
 
 
 def load_droughty_project():
 
-    IdentifyConfigVariables.project_path = Common.project_dir  
-
     with open(IdentifyConfigVariables.project_path) as f:
         droughty_project = yaml.load(f, Loader=yaml.FullLoader)
 
@@ -118,20 +119,20 @@ droughty_project = load_droughty_project()
 @dataclass
 class ProjectVariables:
     
-    environment_profile: str
-    service_account_path: str
-    service_account: str
-    project: str
-    warehouse: str
-    schema: str
+    environment_profile: str.lower
+    service_account_path: str.lower
+    service_account: str.lower
+    project: str.lower
+    warehouse: str.lower
+    schema: str.lower
 
-    role: str
-    password: str
-    database: str
-    account: str
-    user: str
-    snowflake_warehouse: str
-    database: str
+    role: str.lower
+    password: str.lower
+    database: str.lower
+    account: str.lower
+    user: str.lower
+    snowflake_warehouse: str.lower
+    database: str.lower
         
 def assign_project_variables():
 
@@ -210,15 +211,19 @@ project_variables = assign_project_variables()
 @dataclass
 class ExploresVariables:
 
-    explore_tables: str
-    dimensional_inference: str
-    single_list_tables: str
-    flat_list: str 
-    final_list: str
-    join_key_list: str
-    test_schemas: str
-    dbml_schemas: str
-    parent_table_name: str
+    explore_tables: str.lower
+    dimensional_inference: str.lower
+    single_list_tables: str.lower
+    flat_list: str .lower
+    final_list: str.lower
+    join_key_list: str.lower
+    test_schemas: str.lower
+    dbml_schemas: str.lower
+    parent_table_name: str.lower
+    lookml_path: str.lower
+    dbml_path: str.lower
+    cube_path: str.lower
+    dbt_path: str.lower
 
 def assign_explore_variables():
 
@@ -236,12 +241,21 @@ def assign_explore_variables():
 
             ExploresVariables.dbml_schemas = (droughty_project.get("dbml_schemas"))
 
+            try: 
+
+                ExploresVariables.lookml_path = (droughty_project.get("lookml_path"))  
+                ExploresVariables.dbml_path = (droughty_project.get("dbml_path"))  
+                ExploresVariables.cube_path = (droughty_project.get("cube_path"))  
+                ExploresVariables.dbt_path = (droughty_project.get("dbt_path"))  
+            except:
+
+                pass     
+
             try:
 
                 parent_table_path = "explores.parent_table"
                 actual = glom.glom(droughty_project, parent_table_path)
                 ExploresVariables.parent_table_name = ''.join(actual)
-
             except:
 
                 pass
