@@ -16,8 +16,11 @@ import git
 import droughty.cube_parser.cube as cube
 
 from droughty.cube_base_dict import cube_base_dict
-from droughty.config import ProjectVariables
-
+from droughty.config import (
+    ProjectVariables,
+    ExploresVariables,
+    IdentifyConfigVariables
+)
 def get_all_values(nested_dictionary):
 
     for key,value in nested_dictionary.items():
@@ -94,11 +97,17 @@ git_def_path = get_git_root(os.getcwd())
 
 def measure_output():
     
-    git_path = git_def_path
+    if ExploresVariables.cube_path == None:
+ 
+        git_path = IdentifyConfigVariables.git_path
 
-    rel_path = "schema"
+        rel_path = "schema"
 
-    path = os.path.join(git_path, rel_path)
+        path = os.path.join(git_path, rel_path)
+
+    elif ExploresVariables.cube_path != None:
+
+        path = os.path.join(IdentifyConfigVariables.git_path,ExploresVariables.cube_path)
 
     if not os.path.exists(path):
         os.makedirs(path)
