@@ -16,22 +16,26 @@ from droughty.dbml_base_dict import dbml_dict
 from droughty.config import (
     ProjectVariables,
     ExploresVariables,
-    get_git_root
+    IdentifyConfigVariables
 )
 
 try: 
 
     def get_all_values(nested_dictionary):
 
-        rel_path = "db_docs"
+        if ExploresVariables.dbml_path == None:
 
-        path = os.path.join(get_git_root(os.getcwd()), rel_path)
+            rel_path = "db_docs"
+
+            path = os.path.join(IdentifyConfigVariables.git_path, rel_path)
+
+        elif ExploresVariables.dbml_path != None:
+
+            path = os.path.join(IdentifyConfigVariables.git_path,ExploresVariables.dbml_path)
 
         if not os.path.exists(path):
             os.makedirs(path)
 
-            #if key[0] in ExploresVariables.dbml_schemas:
-
         for schema in ExploresVariables.dbml_schemas:
     
             filename = ProjectVariables.environment_profile+'_'+schema+'.dbml'
@@ -58,13 +62,7 @@ try:
 
                     for key,value in value.items():
 
-                        if "pk" not in key[0] and "fk" not in key[0]:
-
-                            dimension = key[0]+" "+key[1]
-
-                            print(dimension)
-
-                        elif "pk" in key[0]:
+                        if "pk" in key[0]:
 
                             dimension = key[0]+" "+key[1]+" [pk]"
 
@@ -82,6 +80,13 @@ try:
 
                             print(dimension)
 
+                        elif "pk" not in key[0] and "fk" not in key[0]:
+
+                            dimension = key[0]+" "+key[1]
+
+                            print(dimension)
+
+
                         else:   
 
                             pass
