@@ -14,6 +14,10 @@ import yaml
 import git
 
 from droughty.lookml_explore_dict import looker_explore_dict,ExploreDictVariables
+from droughty.config import (
+    ExploresVariables,
+    IdentifyConfigVariables
+)
 
 
 def get_all_values(nested_dictionary):
@@ -112,12 +116,18 @@ git_def_path = get_git_root(os.getcwd())
 
 
 def explore_output():
+
+    if ExploresVariables.lookml_path == None:
     
-    git_path = git_def_path
+        git_path = git_def_path
 
-    rel_path = "lookml/base"
+        rel_path = "lookml/base"
 
-    path = os.path.join(git_path, rel_path)
+        path = os.path.join(git_path, rel_path)
+
+    elif ExploresVariables.lookml_path != None:
+
+        path = os.path.join(IdentifyConfigVariables.git_path,ExploresVariables.lookml_path)
 
     if not os.path.exists(path):
         os.makedirs(path)
